@@ -2,22 +2,19 @@ package Business::CPI::Gateway::Base;
 # ABSTRACT: Father of all gateways
 use Moo;
 use Locale::Currency ();
-use Email::Valid ();
 use Business::CPI::EmptyLogger;
 use Class::Load qw/load_first_existing_class/;
 use HTML::Element;
 use Data::Dumper;
 
-our $VERSION = '0.903'; # VERSION
+our $VERSION = '0.904'; # VERSION
 
 has receiver_email => (
-    isa => sub {
-        die "Must be a valid e-mail address"
-            unless Email::Valid->address( $_[0] );
-    },
     is => 'ro',
 );
 
+sub receiver_id { goto \&receiver_email }
+
 has currency => (
     isa => sub {
         my $curr = uc($_[0]);
@@ -37,8 +34,13 @@ has log => (
     default => sub { Business::CPI::EmptyLogger->new },
 );
 
-has checkout_url => (
+has checkout_with_token => (
     is => 'ro',
+    default => sub { 0 },
+);
+
+has checkout_url => (
+    is => 'rw',
 );
 
 has checkout_form_http_method => (
@@ -56,14 +58,17 @@ has checkout_form_submit_value => (
     default => sub { '' },
 );
 
+has checkout_form_submit_image => (
+    is => 'ro',
+    default => sub { '' },
+);
+
 has form_encoding => (
     is      => 'ro',
     # TODO: use Encode::find_encoding()
     default => sub { 'UTF-8' },
 );
 
-# TODO: submit image
-
 sub new_cart {
     my ( $self, $info ) = @_;
 
@@ -101,7 +106,60 @@ sub new_cart {
     );
 }
 
-sub get_hidden_inputs { () }
+sub map_object {
+    my ($self, $map, $obj) = @_;
+
+    my @result;
+
+    while (my ($bcpi_key, $gtw_key) = each %$map) {
+        my $value = $obj->$bcpi_key;
+        next unless $value;
+
+        my $name = $gtw_key;
+
+        if (ref $gtw_key) {
+            $name  = $gtw_key->{name};
+            $value = $gtw_key->{coerce}->($name);
+        }
+
+        push @result, ( $name, $value );
+    }
+
+    return @result;
+}
+
+sub _get_hidden_inputs_for_cart {
+    my ($self, $cart) = @_;
+
+    return $self->map_object( $self->_checkout_form_cart_map, $cart );
+}
+
+sub _get_hidden_inputs_for_buyer {
+    my ($self, $buyer) = @_;
+
+    return $self->map_object( $self->_checkout_form_buyer_map, $buyer );
+}
+
+sub _get_hidden_inputs_for_items {
+    my ($self, $items) = @_;
+    my @result;
+    my $i = 1;
+
+    for my $item (@$items) {
+        push @result,
+          $self->map_object( $self->_checkout_form_item_map( $i++ ), $item );
+    }
+
+    return @result;
+}
+
+sub _get_hidden_inputs_main {
+    my $self = shift;
+
+    return $self->map_object( $self->_checkout_form_main_map, $self );
+}
+
+sub get_hidden_inputs { shift->_unimplemented }
 
 sub get_form {
     my ($self, $info) = @_;
@@ -133,30 +191,41 @@ sub get_form {
         );
     }
 
-    my @value = ();
+    my %submit = (
+        name  => $self->checkout_form_submit_name,
+        type  => 'submit',
+    );
+
     if (my $value = $self->checkout_form_submit_value) {
-        @value = (value => $value);
+        $submit{value} = $value;
+    }
+
+    if (my $src = $self->checkout_form_submit_image) {
+        $submit{src}  = $src;
+        $submit{type} = 'image';
     }
 
     $form->push_content(
-        HTML::Element->new(
-            'input',
-            type  => 'submit',
-            name  => $self->checkout_form_submit_name,
-            @value
-        )
+        HTML::Element->new( 'input', %submit )
     );
 
     return $form;
 }
 
-sub get_notification_details {}
+sub get_notification_details { shift->_unimplemented }
 
-sub query_transactions {}
+sub query_transactions { shift->_unimplemented }
 
-sub get_transaction_details {}
+sub get_transaction_details { shift->_unimplemented }
 
-sub notify {}
+sub notify { shift->_unimplemented }
+
+sub get_checkout_code { shift->_unimplemented }
+
+sub _unimplemented {
+    my $self = shift;
+    die "Not implemented.";
+}
 
 1;
 
@@ -172,13 +241,21 @@ Business::CPI::Gateway::Base - Father of all gateways
 
 =head1 VERSION
 
-version 0.903
+version 0.904
 
 =head1 ATTRIBUTES
 
+=head2 receiver_id
+
+ID, login or e-mail of the business owner. The way the gateway uniquely
+identifies the account owner.
+
 =head2 receiver_email
 
-E-mail of the business owner.
+E-mail of the business owner. Currently, this an alias for receiver_id, for
+backcompatibility. The attribute is called C<receiver_email> only because some
+gateways set the account identification as the user's e-mail, but that's not
+always the case.
 
 =head2 currency
 
@@ -197,6 +274,11 @@ The url for the gateway to postback, notifying payment changes.
 
 The url for the customer to return to, after they finished the payment.
 
+=head2 checkout_with_token
+
+Boolean attribute to determine whether the form will hold the entire cart, or
+it will use the payment token generated for it. Defaults to false.
+
 =head2 checkout_url
 
 The url the application will post the form to. Defined by the gateway.
@@ -213,6 +295,12 @@ Defaults to submit.
 
 Defaults to ''.
 
+=head2 checkout_form_submit_image
+
+If set, makes the submit button become an image. Set this to the URL of the
+image you want to display in the checkout button. Defaults to '' (i.e., no
+image, default brower submit button).
+
 =head2 form_encoding
 
 Defaults to UTF-8.
@@ -228,6 +316,11 @@ Creates a new L<Business::CPI::Cart> connected to this gateway.
 Get the form to checkout. Use the method in L<Business::CPI::Cart>, don't use
 this method directly.
 
+=head2 get_checkout_code
+
+Generates a payment token for a given cart. Do not call this method directly.
+Instead, see L<Business::CPI::Cart/get_checkout_code>.
+
 =head2 get_notification_details
 
 Get the payment notification (such as PayPal's IPN), and return a hashref with
@@ -255,6 +348,12 @@ payment status change to the application. Receives the request as a parameter
 (in a CGI-compatible format), and returns data about the payment. The format is
 still under discussion, and is soon to be documented.
 
+=head2 map_object
+
+Helper method for get_hidden_inputs to translate between Business::CPI and the
+gateway, using methods like checkout_form_items_map, checkout_form_buyer_map,
+etc.
+
 =head1 AUTHOR
 
 André Walker <andre@andrewalker.net>
